==> jc-1.4.0.tar.gz: soot/jimple/toolkits/typing/ClassHierarchy__24ToInt.h <==
// class soot.jimple.toolkits.typing.ClassHierarchy$ToInt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 12e2cc897947b1d6 soot_TypeSwitch
// @dep_class f79dca54eb6f8ef3 soot_jimple_toolkits_typing_ClassHierarchy__24ToInt

// header file dependencies
// @dep_header soot_TypeSwitch

#include "soot/TypeSwitch.h"

#ifndef _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt_H_
#define _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_BooleanType$object;
struct _jc_soot_ByteType$object;
struct _jc_soot_CharType$object;
struct _jc_soot_ShortType$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__241$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object;

typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vmethods	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtable	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *);
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$_init$d2cdcaf878cceaa9(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__241$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$caseBooleanType$06c4be49f62a484d(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_BooleanType$object *);
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$caseByteType$03e7ac421ddf8789(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_ByteType$object *);
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$caseCharType$222ae454bd4c5cbf(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_CharType$object *);
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$caseShortType$18503e8fa30a8705(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_ShortType$object *);
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$defaultCase$de008c64d36e8465(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_Type$object *);
extern struct _jc_soot_Type$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$toInt$7071413ab82b417b(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$caseBooleanType$06c4be49f62a484d;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$caseByteType$03e7ac421ddf8789;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$caseCharType$222ae454bd4c5cbf;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$caseShortType$18503e8fa30a8705;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$defaultCase$de008c64d36e8465;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$toInt$7071413ab82b417b;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vmethods {
	void	(*caseBooleanType$06c4be49f62a484d)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_BooleanType$object *);
	void	(*caseByteType$03e7ac421ddf8789)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_ByteType$object *);
	void	(*caseCharType$222ae454bd4c5cbf)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_CharType$object *);
	void	(*caseShortType$18503e8fa30a8705)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_ShortType$object *);
	void	(*defaultCase$de008c64d36e8465)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_Type$object *);
	struct _jc_soot_Type$object	*(*toInt$7071413ab82b417b)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TypeSwitch$vmethods	soot_TypeSwitch;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vmethods	soot_jimple_toolkits_typing_ClassHierarchy__24ToInt;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_refs {
	struct _jc_soot_Type$object	*result;
	struct _jc_soot_Type$object	*intType;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$refs {
    _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_refs	soot_jimple_toolkits_typing_ClassHierarchy__24ToInt;
    _jc_soot_TypeSwitch$sub_refs	soot_TypeSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TypeSwitch$sub_nonrefs	soot_TypeSwitch;
    _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_nonrefs	soot_jimple_toolkits_typing_ClassHierarchy__24ToInt;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object {
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_ClassHierarchy__24ToInt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/typing/ClassHierarchy__24ToInt.h <==
// class soot.jimple.toolkits.typing.ClassHierarchy$ToInt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 12e2cc897947b1d6 soot_TypeSwitch
// @dep_class f79dca54eb6f8ef3 soot_jimple_toolkits_typing_ClassHierarchy__24ToInt

// header file dependencies
// @dep_header soot_TypeSwitch

#include "soot/TypeSwitch.h"

#ifndef _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt_H_
#define _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_BooleanType$object;
struct _jc_soot_ByteType$object;
struct _jc_soot_CharType$object;
struct _jc_soot_ShortType$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__241$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object;

typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vmethods	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtable	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$_init$d2cdcaf878cceaa9(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$caseBooleanType$06c4be49f62a484d(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_BooleanType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$caseByteType$03e7ac421ddf8789(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_ByteType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$caseCharType$222ae454bd4c5cbf(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_CharType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$caseShortType$18503e8fa30a8705(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_ShortType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$defaultCase$de008c64d36e8465(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method$toInt$7071413ab82b417b(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$caseBooleanType$06c4be49f62a484d;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$caseByteType$03e7ac421ddf8789;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$caseCharType$222ae454bd4c5cbf;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$caseShortType$18503e8fa30a8705;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$defaultCase$de008c64d36e8465;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$method_info$toInt$7071413ab82b417b;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vmethods {
	void	(*caseBooleanType$06c4be49f62a484d)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_BooleanType$object *) _JC_JCNI_ATTR;
	void	(*caseByteType$03e7ac421ddf8789)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_ByteType$object *) _JC_JCNI_ATTR;
	void	(*caseCharType$222ae454bd4c5cbf)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_CharType$object *) _JC_JCNI_ATTR;
	void	(*caseShortType$18503e8fa30a8705)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_ShortType$object *) _JC_JCNI_ATTR;
	void	(*defaultCase$de008c64d36e8465)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*toInt$7071413ab82b417b)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TypeSwitch$vmethods	soot_TypeSwitch;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vmethods	soot_jimple_toolkits_typing_ClassHierarchy__24ToInt;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_refs {
	struct _jc_soot_Type$object	*result;
	struct _jc_soot_Type$object	*intType;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$refs {
    _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_refs	soot_jimple_toolkits_typing_ClassHierarchy__24ToInt;
    _jc_soot_TypeSwitch$sub_refs	soot_TypeSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TypeSwitch$sub_nonrefs	soot_TypeSwitch;
    _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$sub_nonrefs	soot_jimple_toolkits_typing_ClassHierarchy__24ToInt;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object {
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$vtype _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_ClassHierarchy__24ToInt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt_H_ */
